#
# spec file for package kwayland
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           kwayland
Version:        5.116.0
Release:        1.6
Summary:        KDE Wayland library
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  libQt5Gui-private-headers-devel >= %{qt5_version}
BuildRequires:  libqt5-qtwayland-private-headers-devel >= %{qt5_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(PlasmaWaylandProtocols) >= 1.2.1
BuildRequires:  cmake(Qt5Concurrent) >= %{qt5_version}
BuildRequires:  cmake(Qt5Gui) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5WaylandClient) >= %{qt5_version}
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(wayland-client) >= 1.15.0
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-server) >= 1.15.0
%requires_eq    libQt5Gui5
Provides:       libKF5WaylandClient5 = %{version}
Obsoletes:      libKF5WaylandClient5 <= %{version}
Provides:       libKF5WaylandServer5 = %{version}
Obsoletes:      libKF5WaylandServer5 <= %{version}

%description
KWayland provides a Qt-style Client and Server library wrapper for the Wayland libraries.

%package devel
Summary:        KDE Wayland library: Build Environment
Requires:       %{name} = %{version}
Requires:       cmake(Qt5Gui) >= %{qt5_version}

%description devel
KWayland provides a Qt-style Client and Server library wrapper for the Wayland libraries.

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%ldconfig_scriptlets

%files
%license LICENSES/*
%{_kf5_debugdir}/*.categories
%{_kf5_debugdir}/*.renamecategories
%{_kf5_libdir}/libKF5WaylandClient.so.*
%{_kf5_libdir}/libKF5WaylandServer.so.*

%files devel
%{_kf5_includedir}/
%{_kf5_libdir}/cmake/KF5Wayland/
%{_kf5_libdir}/libKF5WaylandClient.so
%{_kf5_libdir}/libKF5WaylandServer.so
%{_kf5_libdir}/pkgconfig/KF5WaylandClient.pc
%{_kf5_mkspecsdir}/qt_KWaylandClient.pri
%{_kf5_mkspecsdir}/qt_KWaylandServer.pri
%{_libexecdir}/org-kde-kf5-kwayland-testserver

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- No code change since 5.115.0
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- No code change since 5.112.0
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- Changes since 5.109.0:
  * Unbreak build where XLib's Bool definition harms moc generated code
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Add explicit moc includes to sources for moc-covered headers
  * Unbreak build where XLib's Bool definition harms moc
    generated code
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- No code change since 5.105.0
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- No code change since 5.104.0
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- No code change since 5.103.0
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- No code change since 5.102.0
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Make sure that HAVE_MEMFD is defined to 0 if not found
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * client: Add F_SEAL_SHRINK seal to shm pool backing file
  * client: Expose concrete xdg-shell class implementations
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * [registry] Bump PlasmaWindowManagement version to 16
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Fix compile error with wl_output < v4
  * PlasmaWindowManagement: Avoid unbounded recursion and delay in readData (kde#453124)
  * client/plasmashell: fix applet popups displacing other windows (kde#459523)
  * client/plasmashell: add fallback for applet popups
  * require PlasmaWaylandProtocols 1.9.0 and bump supported plasmashell version to 8
  * .gitlab-ci.yml: enable static builds
  * ConnectionThread: connect by symbol rather than by name
  * ConnectionThread: Move event dispatcing into a separate method
  * ConnectionThread: Make sure we consume properly the threads
  * Add support for wl_output version 4
- Drop patch, merged upstream:
  * 0001-client-plasmashell-add-fallback-for-applet-popups.patch
* Thu Sep 22 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream fix (kde#459188)
  * 0001-client-plasmashell-add-fallback-for-applet-popups.patch
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Add FreeBSD Qt6 CI support
  * Auto cleanup the dangling KWayland::Client::Surface returned from fromWindow
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * Unset wl_display global filter upon filtered display destruction.
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * Implement PlasmaWindowModel::itemData to expose all the roles
  * Remove extra ';'
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * Add AppletPopup window type to PlasmaShellSurface
  * fix up foreign docs
  * Raise minimum plasma-wayland-proto version to 1.7.0
  * Fix include dir in the generated pri file
  * client: Bump plasmashell version to 7 (kde#453578)
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * client: implement plasma-surface openUnderCursor
  * Fix since version
  * Fix include path in the generated pkgconfig file
  * [plasmawindowmanagement] Add resourceName
  * client: Bump plasmashell version to 7 (kde#453578)
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Install Client headers in a dirs hierarchy matching the C++ namespaces
  * We don't actually need Qt6WaylandCompositor
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Check executables exist in PATH before passing them to QProcess
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%_libdir/libexec with %%_libexecdir (boo#1174075)
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Ensure when unmapped is emitted, ::windows() will not contain unmapped window.
  * Fix wayland registry test
  * Add Linux Qt6 CI
  * Don't use hard-coded versions with targets and variables
  * Install pkg-config file
  * Deprecate PlasmaWindowModel::requestVirtualDesktop()
  * kwayland server has been moved to plasma kwayland-server since 5.73
  * src/client: wrap deprecated methods in deprecation macros
  * Change the build system to enable building with Qt6
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Make linux/input.h a hard dependency
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Use pointer-to-member-function signal/slot syntax
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Add FreeBSD CI
  * Fix building waylandservertest when Qt was built without GLib support
  * Correct the eglQueryWaylandBufferWL_func prototype
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
  * KWayland depends on libraries/plasma-wayland-protocols
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * Implement set_frost in contrast protocol
  * Implement org_kde_plasma_window_management::send_to_output
  * Decouple activation feedback from plasma window management global
  * Port QStringRef (deprected) to QStringView
  * plasma-window-management: Support new activation concepts
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Fix check for mmap failure (kde#421868)
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Fix build
  * Remove not necessary forward declaration
  * Use const'ref
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Use protocol files from plasma-wayland-protocols
  * Bump required CMake version to 3.16
  * Fix windowmanagement test
  * Update Plasma Wayland Protocols dependency to 1.3.0
  * Do not emit Surface::leave twice when an output is removed
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Too many changes to list here.
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * Fixes DTD check errors and a typo
  * Add the activity management protocol client implementation
  * Bump plasma-wayland-protocols dependency to 1.2.1
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- No code change since 5.79.0
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- No code change since 5.78.0
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Update test away from xdgshellv6 to stable
  * Pass parent to QVBoxLayout ctor instead of calling setLayout()
  * Don't include QtTest as it includes all QtCore includes
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Compile without deprecated method
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * Provide convenience methods around wl_data_offet_accept()
  * Mark enums in a Q_OBJECT, Q_ENUM
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * fix compile, last() is no iterator
  * Don't cache QList::end() iterator if erase() is used
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * [autotests] Skip failing unit test
  * Use Q_DECLARE_OPERATORS_FOR_FLAGS in same namespace as flags definition
  * Remove obsolete COPYING files
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * plasma-window-management: Adapt to changes in the protocol
  * PlasmaWindowManagement: adopt changes in the protocol
  * Use KF-standardized Qt logging categories
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- No code change since 5.71.0
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Fix test-building on FreeBSD
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * [Wayland] Add to PlasmaWindowManagement protocol windows stacking order
  * Add wrapper for wl_global_remove
  * [server] Add some sub-surface life cycle signals
  * [autotests] Optimistic attempt to fix RemoteAccessTest reilability
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Too many changes since 5.68.0, only listing bugfixes:
  * Pass a dedicated fd to each keyboard for the xkb  keymap (kde#381674)
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Add application menu dbus paths to org_kde_plasma_window interface
  * Registry: don't destroy the callback on globalsync
  * Use ecm_qt_install_logging_categories over manual categories file
  * [surface] Fix buffer offset when attaching buffers to surfaces
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- No code change since 5.66.0.
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * [plasmashell] Update docs for panelTakesFocus to make it generic
  * [plasmashell] Add signal for panelTakesFocus changing
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Make test more tolerant timing-wise
  * Don't use nullptr to flags
  * [server] Do not own dmabuf implementation
  * [server] Make double-buffered properties in xdg-shell double-buffered
  * Add missing include for Qt 5.14 build
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * FakeInput: add support for keyboard key press and release
  * Use ECMGenerateExportHeader to manage deprecated API better
  * Fix non-integer scale copy on creation of OutputChangeSet
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * [KWayland] Port away from deprecated API in Qt 5.14
  * Sort files alphabetically in cmake list
  * Improve documentation
  * Use const_iterator
  * Remove capture of this in lambda
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * [server] Wrap proxyRemoveSurface in smart pointer
  * [server] Use cached current mode more and assert validness
  * [server] Cache current mode
  * Implement zwp_linux_dmabuf_v1
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Use wayland-protocols
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop conditionals for no longer supported distribution versions
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Include a description
  * Proof of concept of a wayland protocol to allow the keystate dataengine to work
  * Use new logging category directory
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Allow compositors to send discrete axis values
  * Use QVariant::fromValue directly
  * Implement set_window_geometry
  * Implement wl_surface::damage_buffer
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Add CriticalNotification window type to PlasmaShellSurface protocol
  * Implement wl_eglstream_controller Server Interface
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * it compiles fine without foreach
  * Hopefully fix flaky remote access test
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Only commit XdgOutput::done if changed
  * FakeInput: add support for pointer move with absolute coordinates
  * Add explicit SurfaceInterface::commited signal
  * Add missing XdgShellPopup::ackConfigure
  * Update copy paste error in XdgShellPopupStable member vars
  * [server] Add surface data proxy mechanism
  * [server] Add selectionChanged signal
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * [server] Generate correct touch ids
  * [autotests] Stabilize testWindowmanagement
  * Make XdgTest spec compliant
  * Add option to use wl_display_add_socket_auto
  * [server] Send initial org_kde_plasma_virtual_desktop_management.rows
  * Add rows info to the plasma virtual desktop protocol
  * [client] Wrap wl_shell_surface_set_{class,title}
  * Guard resource deletion in OuptutConfiguration::sendApplied
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Add clarifying about using both KDE's ServerDecoration and XdgDecoration
  * Update @since information
  * Xdg Decoration Support
  * Fix XDGForeign Client header installs
  * [server] Touch drag support
  * [server] Allow multiple touch interfaces per client
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Autogenerate logging file + fix categories file
  * Use new syntax
  * Remove virtual keyword
  * Use lambdas instead of std::bind()
  * Add VirtualDesktops to PlasmaWindowModel
  * Update PlasmaWindowModel test to reflect VirtualDesktop changes
  * Cleanup windowInterface in tests before windowManagement is destroyed
  * Delete the correct item in removeDesktop
  * Cleanup Virtual Desktop Manager list entry in PlasmaVirtualDesktop destructor
  * Correct version of newly added PlasmaVirtualDesktop interface
  * [server] Text input content hint and purpose per protocol version
  * [server] Put text-input (de-)activate, en-/disable callbacks in child classes
  * [server] Put set surrounding text callback with uint in v0 class
  * Remove qt include prefix
  * Cleanup comment typos
  * [server] Put some text-input v0 exclusive callbacks in v0 class
  * normalize signal/slot
  * Fix build with Qt <5.10 (no support for QCOMPARE(uint, int)
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Fix build with Qt <5.10 (no support for QCOMPARE(uint, int)
  * Add KWayland virtual desktop protocol
  * Add unit test for subsurface input mask detection
  * Guard data source being deleted before processing dataoffer receive event (kde#400311)
  * [server] Respect input region of sub-surfaces on pointer surface focus
  * [test/xdgtest] Create/destroy popup on click
  * [xdgshell] Add positioner constraint adjustment flag operators
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Don't silently error if damage is sent before buffer
  * [server] Do not return early on fail in touchDown fall back code
  * Minor: Add a few nullptrs
  * Minor: Include Qt dirs as SYSTEM includes
  * Minor: Fix CMake AUTOMOC warning
  * Fix minor EBN issues
  * [server] Fix remote access buffer handling when output not bound
  * [autotests] Compare booleans to booleans
  * Fix minor EBN issues
  * [server] Do not try to create data offers without source
  * [server] Abort drag start on correct conditions and without posting error
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Sync set/send/update methods
  * Add serial number and EISA ID to OutputDevice interface
  * Fix unit test
  * Output device color curves correction
  * Fix memory management in WaylandOutputManagement
  * Isolate every test within WaylandOutputManagement
  * OutputManagement fractional scaling
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Cleanup RemoteAccess buffers on aboutToBeUnbound instead of object destruction
  * Support cursor hints on locked pointer
  * Reduce unnecessary long wait times on failing signal spies
  * Fix selection and seat auto tests
  * Populate shell version documentation
  * Fix compiler warning about virtual overloads in XdgShell
  * Replace remaining V5 compat global includes
  * Add XDG WM Base support to our XDGShell API
  * Make XDGShellV5 co-compilable with XDGWMBase
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Fix some of cppcheck warnings
  * [server] Send frame event instead of flush on relative pointer motion (kde#395815)
  * Fix XDGV6 popup test
  * Fix stupid copy paste bug in XDGShellV6 Client
  * Do not cancel old clipboard selection if it is same as the new one. (kde#395366)
  * Fix compiler warning about hidden virtual overloads
  * Honor BUILD_TESTING
  * Fix some spelling issues suggested by new linter tool
  * Add the arclint file in kwayland
  * Fix 'unused parameter' warnings
  * Documentation fix
  * [server] Small code cleanup in SurfaceInterface
  * Fixup @since for skip switcher API
- Dropped patches, now upstream:
  * 0001-Do-not-cancel-old-clipboard-selection-if-it-is-same-.patch
* Thu Jun 21 2018 fabian@ritter-vogt.de
- Add patch to fix copy-paste from GTK3 applications (boo#1097606):
  * 0001-Do-not-cancel-old-clipboard-selection-if-it-is-same-.patch
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * [autotests] Fix surface destroy test
  * Use override
  * Increase org_kde_plasma_shell interface version
  * Add "SkipSwitcher" to API
  * Set @since version number for XDGOutput
  * Add XDG Output Protocol
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Improve protocols documentation
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Add Remote Access interface to KWayland
  * [server] Add support for the frame semantics of Pointer version 5 (kde#389189)
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Implement releasing of client-freed output
  * [server] Properly handle the situation when the DataSource for a drag gets destroyed (kde#389221)
  * [server] Don't crash when a subsurface gets commited whose parent surface got destroyed (kde#389231)
- Dropped patches, now upstream:
  * 0001-server-Don-t-crash-when-a-subsurface-gets-commited-w.patch
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Fix typo
* Tue Feb  6 2018 lbeltrame@kde.org
- Add 0001-server-Don-t-crash-when-a-subsurface-gets-commited-w.patch
  * Upstream fix to prevent kwin from crashing when opening
    systemsettings (kde#389231)
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Minor doxygen change to group new bind/create methods
  * Fix naming inconsistency
  * Resolve some merge issues
  * Unit test for Server Decoration Palette
  * Create interface for passing server decoration palettes
  * Explicitly include std::bind functions
  * [server] Add a method IdleInterface::simulateUserActivity
  * Fix regression caused by backward compatibility support in data source
  * Fix @since version tags
  * Add support for version 3 of data device manager interface (kde#386993)
  * Scope exported/imported objects to the test
  * Fix ASAN warning on TestXdgForeign
  * Replace QCOMPARE(nullptr) with QVERIFY
  * Fix error in WaylandSurface::testDisconnect
  * Explicit QCOMPARE(QString,QString)
  * Add explicit AppMenu protocol
  * Fix ASAN warnings in XDGForeignV2Interface
  * Fix exlude generated file from automoc feature
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Fix testWaylandFullscreenShell.
  * Expose wl_display_set_global_filter as a virtual method
  * Fix kwayland-testXdgShellV6.
  * Add support for zwp_idle_inhibit_manager_v1
  * [server] Support inhibiting the IdleInterface
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * [client] Drop the checks for platformName being "wayland"
  * Don't duplicate connect to wl_display_flush
  * don't qcompare with nullptr
  * Wayland foreign protocol
  * Revert "Expose wl_display_set_global_filter as a virtual method"
  * Expose wl_display_set_global_filter as a virtual method
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Only send OutputConfig sendApplied / sendFailed to the right resource
  * Add missing command macro
  * Don't crash if a client (legally) uses deleted global contrast manager
  * Don't crash if a client (legally) uses a deleted global
  * Update @since docs
  * Missing licenses
  * Support XDG v6
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Treat input RGB buffers as premultiplied
  * Update SurfaceInterface outputs when an output global gets destroyed
  * KWayland::Client::Surface track output destruction
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
  * Avoid sending data offers from an invalid source. (kde#383054)
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Make unittest independent from the location of the executable.
  * autotests: prepare for CMAKE_RUNTIME_OUTPUT_DIRECTORY being set
  * Destroy all kwayland objects created by registry when it is destroyed
  * Emit connectionDied if the QPA is destroyed
  * [client] Track all created ConnectionThreads and add API to access them
  * [server] Send text input leave if focused surface gets unbound
  * [server] Send pointer leave if focused surface gets unbound
  * Drop unused variable
  * [client] Properly track enteredSurface in Keyboard
  * [server] Send keyboard leave when client destroys the focused surface (kde#382280)
  * check Buffer validity (kde#381953)
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * [autotests/server] Check whether test is run as root
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Autotests: solve warning for QProcess::ProcessState metatype registration
  * Fix for TestQtSurfaceExtension in path with spaces
  * API dox: add some minimal docs to more class to have them covered by doxygen
  * API dox: add some minimal docs to class to have them covered by doxygen
  * API dox: Use doxygen notation to have comments used
  * API dox: fix @link usage
  * add requestToggleKeepAbove/below
  * Keep QIcon::fromTheme in main thread
  * Remove pid changedSignal in Client::PlasmaWindow
  * add pid to plasma window management protocol
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Validate surface is valid when sending TextInput leave event
  * Fix autotests on the FreeBSD CI.
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Add support for wl_shell_surface::set_popup and popup_done
  * Upgrade KF5 version to 5.33.0.
* Fri Apr  7 2017 alarrosa@suse.com
- Drop fix-wayland-1.3-dependency.diff which isn't needed anymore
  since SLE12 SP2.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * [client] Fix nullptr dereference in ConfinedPointer
    and LockedPointer
  * [client] Install pointerconstraints.h
  * [server] Fix regression in
    SeatInterface::end/cancelPointerPinchGesture
  * Implementation of PointerConstraints protocol
  * [server] Reduce overhead of pointersForSurface
  * Return SurfaceInterface::size in global compositor space
  * [tools/generator] Generate enum FooInterfaceVersion on
    server side
  * [tools/generator] Wrap wl_fixed request args in
    wl_fixed_from_double
  * [tools/generator] Generate implementation of
    client side requests
  * [tools/generator] Generate client side resource factories
  * [tools/generator] Generate callbacks and listener
    on client side
  * [tools/generator] Pass this as q pointer to
    Client::Resource::Private
  * [tools/generator] Generate Private::setup(wl_foo *arg)
    on client side
  * Implementation of PointerGestures protocol
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Wed Nov 16 2016 hrvoje.senjan@gmail.com
- Rebase fix-wayland-1.3-dependency.diff
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Improved relocatability of CMake export
  * [tools] Fix generation of wayland_pointer_p.h
  * [tools] Generate eventQueue methods only for global classes
  * [server] Fix crash on updating focused keyboard surface
  * [server] Fix possible crash on creation of DataDevice
  * [server] Ensure we have a DataSource on the DataDevice
    in setSelection
  * [tools/generator] Improve resource destruction on server side
  * Add request to have focus in a PlasmaShellSurface of Role Panel
  * Add auto-hiding panel support to PlasmaShellSurface interface
  * Support passing generic QIcon through PlasmaWindow interface
  * [server] Implement the generic window property
    in QtSurfaceExtension
  * [client] Add methods to get ShellSurface from a QWindow
  * [server] Send pointer events to all wl_pointer resources
    of a client
  * [server] Don't call wl_data_source_send_send if
    DataSource is unbound
  * [server] Use deleteLater when a ClientConnection gets destroyed
    (kde#370232)
  * Implement support for the relative pointer protocol
  * [server] Cancel previous selection from SeatInterface::setSelection
  * [server] Send key events to all wl_keyboard resources of a client
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * [server] Don't send key release for not pressed keys and
    no double key press (kde#366625)
  * [server] When replacing the clipboard selection previous
    DataSource needs to be cancelled (kde#368391)
  * Add support for Surface enter/leave events
  * [client] Track all created Outputs and add static get method
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Make linux/input.h compile time optional
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Wed Aug 10 2016 alarrosa@suse.com
- Rebase fix-wayland-1.3-dependency.diff
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * [client] Use a QPointer for the enteredSurface in Pointer
  * Expose Geometry in PlasmaWindowModel
  * Add a geometry event to PlasmaWindow
  * [src/server] Verify that surface has a resource before sending pointer enter
  * Add support for xdg-shell
  * [server] Properly send a selection clear prior to keyboard focus enter
  * [server] Handle no XDG_RUNTIME_DIR situation more gracefully
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Add a parent_window event to Plasma Window interface
  * Properly handle destroying a Pointer/Keyboard/Touch resource
  * [server] Delete dead code: KeyboardInterface::Private::sendKeymap
  * [server] Add support for setting the clipboard selection
    DataDeviceInterface manually
  * [server] Ensure that Resource::Private::get returns nullptr
    if passed a nullptr
  * [server] Add resource check in QtExtendedSurfaceInterface::close
  * [server] Unset SurfaceInterface pointer in referenced objects
    when being destroyed
  * [server] Fix error message in QtSurfaceExtension Interface
  * [server] Introduce a Resource::unbound signal emitted from
    unbind handler
  * [server] Don't assert when destroying a still
    referenced BufferInterface
  * Add destructor request to org_kde_kwin_shadow and
    org_kde_kwin_shadow_manager
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * [client] Don't check resource version for PlasmaWindow
  * Introduce an initial state event into Plasma Window protocol
  * [server] Trigger error if a transient request tries to parent
    to itself
  * [server] Properly handle the case that a PlasmaWindow is unmapped
    before client bound it
  * [server] Properly handle destructor in SlideInterface
  * Add support for touch events in fakeinput protocol and interface
  * [server] Standardize the destructor request handling for Resources
  * Implement wl_text_input and zwp_text_input_v2 interfaces
  * [server] Prevent double delete of callback resources
    in SurfaceInterface
  * [server] Add resource nullptr check to ShellSurfaceInterface
  * [server] Compare ClientConnection instead of wl_client
    in SeatInterface
  * [server] Improve the handling when clients disconnect
  * server/plasmawindowmanagement_interface.cpp - fix -Wreorder warning
  * [client] Add context pointer to connects in PlasmaWindowModel
  * Many fixes related to destruction
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * KWayland is now part of KDE Frameworks
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Wed Dec 23 2015 alarrosa@suse.com
- Add fix-wayland-1.3-dependency.diff again, rebased to apply correctly
  now that there are wayland packages for SLE12 updated with the new
  requirements from wayland 1.7
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
- Drop no longer applicable fix-wayland-1.3-dependency.diff
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Thu Oct 29 2015 alarrosa@suse.com
- Added fix-wayland-1.3-dependency.diff -> changed requirements for
  SLE12, where an older wayland version has been patched to support
  the required features from wayland 1.3.0 needed by kwayland
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
- Merge the two shlib packages into one main one
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Added pkgconfig(egl) BuildRequires
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Drop 0001-Do-not-find-unused-Wayland-components.patch, upstreamed
- Build the server shlib
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Mon Nov  3 2014 hrvoje.senjan@gmail.com
- Added 0001-Do-not-find-unused-Wayland-components.patch to drop
  not needed BuildRequires, pkgconfig(wayland-egl)
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Thu Sep 25 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor API improvements since last update
* Mon Sep 22 2014 hrvoje.senjan@gmail.com
- Activate KWayland package - KDE bindings for Wayland protocol and
  library
